@@ -424,11 +424,15 @@ prodStack <- function(x,
   manipulateWidget(
     {
       .tryCloseH5()
-      if (.id <= length(params$x)){
-        widget <- params$x[[max(1, .id)]]$plotWithLegend(.id, areas, main,
-                                                        unit, stack, dateRange,
-                                                        mcYear, legend,
-                                                        stepPlot, drawPoints)
+      
+      # udpate for mw 0.11 & 0.10.1
+      if(!is.null(params)){
+        ind <- .id %% length(params$x)
+        if(ind == 0) ind <- length(params$x)
+        widget <- params$x[[ind]]$plotWithLegend(.id, areas, main,
+                                                 unit, stack, dateRange,
+                                                 mcYear, legend,
+                                                 stepPlot, drawPoints)
         controlWidgetSize(widget, language)
       } else {
         return (combineWidgets(.getLabelLanguage("No data for this selection", language)))
@@ -500,14 +504,24 @@ prodStack <- function(x,
     ),
     
     sharerequest = mwSharedValue({
+      tmp_tables <- tables
+      if(is.null(tmp_tables) | (!is.null(tmp_tables) && is.function(tmp_tables))){
+        tmp_tables <- paramsH5[["tabl"]][paramsH5[["tabl"]] %in% c("areas", "districts")][1]
+      }
+      
+      tmp_timeSteph5 <- timeSteph5
+      if(is.null(tmp_timeSteph5)){
+        tmp_timeSteph5 <- paramsH5$timeStepS[1]
+      }
+      
       if (length(meanYearH5) > 0){
         if (meanYearH5){
-          list(timeSteph5_l = timeSteph5, mcYearh_l = NULL, tables_l = tables)
+          list(timeSteph5_l = tmp_timeSteph5, mcYearh_l = NULL, tables_l = tmp_tables)
         } else {
-          list(timeSteph5_l = timeSteph5, mcYearh_l = mcYearH5, tables_l = tables)
+          list(timeSteph5_l = tmp_timeSteph5, mcYearh_l = mcYearH5, tables_l = tmp_tables)
         }
       } else {
-        list(timeSteph5_l = timeSteph5, mcYearh_l = mcYearH5, tables_l = tables)
+        list(timeSteph5_l = tmp_timeSteph5, mcYearh_l = mcYearH5, tables_l = tmp_tables)
       }
     }),
     
