@@ -17,16 +17,45 @@ observeEvent(
   }
 )
 
+rdsData <- reactive({
+  req(input$fileRDS)
+  file <- input$fileRDS
+  if(is.null(file)) return(NULL)
+  data <- tryCatch(readRDS(file$datapath), error = function(e) NULL)
+  if(!is.null(data)){
+    if(!"antaresData" %in% class(data)){
+      showModal(modalDialog(
+        title = "Error importing .RDS data",
+        easyClose = TRUE,
+        footer = NULL,
+        "Not an 'antaresData', output of 'readAntares' function."
+      ))
+      data <- NULL
+    }
+  }
+  data
+})
+
+
+
+
+
 output$directory_message <- renderText({
   if(length(input$directory) > 0){
     if(input$directory == 0){
-      antaresViz:::.getLabelLanguage("Please first choose a folder with antares output", current_language$language)
+      antaresViz:::.getLabelLanguage("Or choose a folder with antares output", current_language$language)
     } else {
       antaresViz:::.getLabelLanguage("No antares output found in directory", current_language$language)
     }
   }
 })
 
+
+output$directory_message2 <- renderText({
+  antaresViz:::.getLabelLanguage("Choose a .RDS file with antares output", current_language$language)
+})
+
+
 # list files in directory
 dir_files <- reactive({a
   path <- readDirectoryInput(session, 'directory')
@@ -188,7 +217,7 @@ observe({
       updateSelectInput(session, "rmva_production_h5", paste0(antaresViz:::.getLabelLanguage("production", current_language), " : "), 
                         choices = opts$areaList, selected = NULL)
       
-      
+      updateSelectInput(session, "hvdc",choices = areas[areas!="all"], selected = NULL)
     })
   }
 })
@@ -235,24 +264,24 @@ observe({
   opts <- opts()
   if(!is.null(current_language) & !is.null(opts)) {
     isolate({
-        if(!opts$parameters$general$`year-by-year`){
-          sel <- isolate({input$read_type_mcYears})
-          choices <- c("synthetic")
-          names(choices) <- sapply(choices, function(x){
-            antaresViz:::.getLabelLanguage(x, current_language)
-          })
-          updateRadioButtons(session, "read_type_mcYears", paste0(antaresViz:::.getLabelLanguage("mcYears selection", current_language), " : "),
-                             choices, selected = sel, inline = TRUE)
-          updateCheckboxInput(session, "read_hydroStorage", antaresViz:::.getLabelLanguage("hydroStorage", current_language), FALSE)
-        } else {
-          sel <- isolate({input$read_type_mcYears})
-          choices <- c("synthetic", "all", "custom")
-          names(choices) <- sapply(choices, function(x){
-            antaresViz:::.getLabelLanguage(x, current_language)
-          })
-          updateRadioButtons(session, "read_type_mcYears", paste0(antaresViz:::.getLabelLanguage("mcYears selection", current_language), " : "),
-                             choices, selected = sel, inline = TRUE)
-        }
+      if(!opts$parameters$general$`year-by-year`){
+        sel <- isolate({input$read_type_mcYears})
+        choices <- c("synthetic")
+        names(choices) <- sapply(choices, function(x){
+          antaresViz:::.getLabelLanguage(x, current_language)
+        })
+        updateRadioButtons(session, "read_type_mcYears", paste0(antaresViz:::.getLabelLanguage("mcYears selection", current_language), " : "),
+                           choices, selected = sel, inline = TRUE)
+        updateCheckboxInput(session, "read_hydroStorage", antaresViz:::.getLabelLanguage("hydroStorage", current_language), FALSE)
+      } else {
+        sel <- isolate({input$read_type_mcYears})
+        choices <- c("synthetic", "all", "custom")
+        names(choices) <- sapply(choices, function(x){
+          antaresViz:::.getLabelLanguage(x, current_language)
+        })
+        updateRadioButtons(session, "read_type_mcYears", paste0(antaresViz:::.getLabelLanguage("mcYears selection", current_language), " : "),
+                           choices, selected = sel, inline = TRUE)
+      }
     })
   }
 })
\ No newline at end of file
